@@ -1,7 +1,7 @@
 # Mail::Address.pm
 #
-# Copyright (c) 1995 Graham Barr <Graham.Barr@tiuk.ti.com>. All rights
-# reserved. This program is free software; you can redistribute it and/or
+# Copyright (c) 1995 Graham Barr <gbarr@ti.com>. All rights reserved.
+# This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
 package Mail::Address;
@@ -87,7 +87,7 @@ Unimplemented yet but should return the UUCP canon for the message
 
 =head1 AUTHOR
 
-Graham Barr <Graham.Barr@tiuk.ti.com>
+Graham Barr <gbarr@ti.com>
 
 =head1 COPYRIGHT
 
@@ -100,7 +100,7 @@ as Perl itself.
 use Carp;
 use vars qw($VERSION);
 
-$VERSION = "1.09";
+$VERSION = do { my @r=(q$Revision: 1.11 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r};
 sub Version { $VERSION }
 
 #
