@@ -1,7 +1,7 @@
 # Mail::Field.pm
 #
-# Copyright (c) 1995 Graham Barr <Graham.Barr@tiuk.ti.com>. All rights
-# reserved. This program is free software; you can redistribute it and/or
+# Copyright (c) 1995 Graham Barr <gbarr@ti.com>. All rights reserved.
+# This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
 package Mail::Field;
@@ -130,7 +130,7 @@ C<_header_pkg_name> subroutine in C<Mail::Field>
 
 =head1 AUTHOR
 
-Graham Barr <Graham.Barr@tiuk.ti.com>
+Graham Barr <gbarr@ti.com>
 
 =head1 SEE ALSO
 
@@ -154,7 +154,7 @@ use Carp;
 use strict;
 use vars qw($AUTOLOAD $VERSION);
 
-$VERSION = "1.02";
+$VERSION = do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r};
 
 my %Register = ();	# method => package name translation
 my %Loaded   = ();	# loaded packages
